| Title: | R package Docker Demo |
|---|---|
| Description: | Demonstrates using an R package inside a Docker image. |
| Authors: | Stephen Turner [aut, cre] (ORCID: <https://orcid.org/0000-0001-9140-9028>), VP Nagraj [aut] (ORCID: <https://orcid.org/0000-0003-0060-566X>) |
| Maintainer: | Stephen Turner <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.2.0 |
| Built: | 2026-05-08 06:19:41 UTC |
| Source: | https://github.com/stephenturner/rpdd |
Take that flip it and reverse it
missyelliot(x)missyelliot(x)
x |
A DNA sequence consisting of A, C, G, and T |
A reverse-complemented DNA sequence
missyelliot("GATTACA") missyelliot(c("GATTACA", "CATATTAC"))missyelliot("GATTACA") missyelliot(c("GATTACA", "CATATTAC"))